#!/bin/bash
img_path=""
dfu_path=""
# replace with your image path: /path/to/your/img_packages
default_img_path="."

mcu_img=""

if [ $# -eq 0 ]; then
    echo "using default path: $default_img_path"
    img_path="$default_img_path"
else
    img_path="$1"
fi

if [ x$2 != x"" ];then
    dfu_path="-p $2"
fi

if [ -z "$img_path" ]; then
    echo "Usage: $0 /path/to/your/img_packages"
    exit 0
fi

check_status() {
    if [[ $2 == *"Download done"* ]]; then
        echo "download '$1' success"
    else
        echo "$2"
        exit 1
    fi
}

get_mcu_img() {
    if [[ $1 == *"SIP_Matrix V2.0"* ]]; then
        mcu_img="MCU_S100_V1.0.img"
    else
        echo "!! no mcu interface or mcu interface not support now !!"
        echo "!! run dfu-util -l to check your board type and add it in this script !!"
        exit 1
    fi
}

# bootrom dfu, start hsm
echo "------------ start download hsm ------------"
output=$(dfu-util -d,3652:6610 -a 0 -D "$img_path/cmd_load_hsmfw" ${dfu_path} 2>&1)
check_status "$img_path/cmd_load_hsmfw" "$output"
output=$(dfu-util -d,3652:6610 -a 0 -D "$img_path/hsmfw_se.pkg" ${dfu_path} 2>&1)
check_status "$img_path/hsmfw_se.pkg" "$output"
output=$(dfu-util -d,3652:6610 -a 0 -D "$img_path/cmd_exit_hsmfw" ${dfu_path} 2>&1)
check_status "$img_path/cmd_exit_hsmfw" "$output"
echo "waiting for hsm start..."
sleep 5

# start sbl
echo "------------ start download sbl ------------"
output=$(dfu-util -d,3652:6615 -a 0 -D "$img_path/fpt.img" ${dfu_path} -R 2>&1)
check_status "$img_path/fpt.img" "$output"
sleep 3
output=$(dfu-util -d,3652:6615 -a 0 -D "$img_path/keyimage.img" ${dfu_path} -R 2>&1)
check_status "$img_path/keyimage.img" "$output"
sleep 3
output=$(dfu-util -d,3652:6615 -a 0 -D "$img_path/SBL.img" ${dfu_path} -R 2>&1)
check_status "$img_path/SBL.img" "$output"
sleep 3
output=$(dfu-util -d,3652:6615 -a 0 -D "$img_path/hsmrca.pkg" ${dfu_path} -R 2>&1)
check_status "$img_path/hsmrca.pkg" "$output"
echo "waiting for sbl start..."
sleep 5


# start spl
echo "------------ start download spl ------------"
output=$(dfu-util -d,3652:6620 -a 0 -D "$img_path/spl.img" ${dfu_path} -R 2>&1)
check_status "$img_path/spl.img" "$output"
echo "waiting for spl start..."
sleep 3

# start mcu
echo "------------ start download mcu ------------"
output=$(dfu-util ${dfu_path} -l 2>&1)
get_mcu_img "$output"
output=$(dfu-util -d,3652:6620 -a 0 -D "$img_path/$mcu_img" ${dfu_path} -R 2>&1)
check_status "$img_path/$mcu_img" "$output"
echo "waiting for mcu start..."
sleep 20

# sbl dfu, start uboot
echo "------------ start download bl31 optee uboot ------------"
output=$(dfu-util -d,3652:6625 -a 0 -D "$img_path/acore_cfg.img" ${dfu_path} 2>&1)
check_status "$img_path/acore_cfg.img" "$output"
output=$(dfu-util -d,3652:6625 -a 1 -D "$img_path/bl31.img" ${dfu_path} 2>&1)
check_status "$img_path/bl31.img" "$output"
output=$(dfu-util -d,3652:6625 -a 2 -D "$img_path/optee.img" ${dfu_path} 2>&1)
check_status "$img_path/optee.img" "$output"
output=$(dfu-util -d,3652:6625 -a 3 -D "$img_path/uboot.img" ${dfu_path} -R 2>&1)
check_status "$img_path/uboot.img" "$output"

echo "------------ download all success, start uboot... ------------"
