#!/usr/bin/env python3
# -*- coding: utf-8 -*-
#
import os
import time
import click
import pyftdi
from pyftdi.gpio import GpioAsyncController
import subprocess


def reset_board(dev_filter='', port=0, pin=7):
    gpio = GpioAsyncController()
    gpio.configure('ftdi://ftdi:4232:%s/%d' % (dev_filter, port),
                   direction=(1 << pin))
    pins = gpio.read()
    pins &= ~(1 << pin)
    gpio.write(pins)
    pins |= 1 << pin
    time.sleep(0.2)
    gpio.write(pins)
    gpio.close()
    pass


def get_fdti_filter(tty):
    status, path = subprocess.getstatusoutput(
        'udevadm info -q path %s' % (tty))
    if status != 0:
        return ''

    ftdi_path = os.path.abspath(
        os.path.join('/sys%s' % (path),
                     os.pardir, os.pardir, os.pardir, os.pardir))

    status, busnum = subprocess.getstatusoutput(
        'cat %s' % (os.path.join(ftdi_path, 'busnum')))
    if status != 0:
        return ''
    status, devnum = subprocess.getstatusoutput(
        'cat %s' % (os.path.join(ftdi_path, 'devnum')))
    if status != 0:
        return ''

    return '%x:%x:' % (int(busnum), int(devnum))


def ftdi_io_reset(tty, port=0, pin=7):
    ftdi_filter = get_fdti_filter(tty)
    try:
        reset_board(ftdi_filter, port, pin)
    except pyftdi.usbtools.UsbToolsError:
        pass


@click.command()
@click.argument('tty', type=click.Path(exists=True))
@click.option('port', '--port', type=int, default=0)
@click.option('pin', '--pin', type=int, default=7)
def ftdi_io_reset_cli(tty, port, pin):
    return ftdi_io_reset(tty, port, pin)


if __name__ == '__main__':
    ftdi_io_reset_cli()
